==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/VirtualDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { BaseDataSourceDescriptionMetadata } from "./BaseDataSourceDescriptionMetadata";
import { VirtualDataSourceDescription } from "./VirtualDataSourceDescription";
/**
 * @hidden
 */
export let VirtualDataSourceDescriptionMetadata = /*@__PURE__*/ (() => {
    class VirtualDataSourceDescriptionMetadata extends Base {
        static b(a) {
            if (VirtualDataSourceDescriptionMetadata.a == null) {
                VirtualDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                VirtualDataSourceDescriptionMetadata.c(VirtualDataSourceDescriptionMetadata.a);
            }
            if (a.j(VirtualDataSourceDescriptionMetadata.a)) {
                return;
            }
            a.y(VirtualDataSourceDescriptionMetadata.a);
        }
        static c(a) {
            BaseDataSourceDescriptionMetadata.c(a);
            a.item("IsSectionCollapsable", "Boolean");
            a.item("IsSectionExpandedDefault", "Boolean");
            a.item("PageSizeRequested", "Number:int");
            a.item("MaxCachedPages", "Number:int");
            a.item("ActualPageSize", "Number:int");
            a.item("ConcurrencyTag", "String");
            a.item("IsBatchingEnabled", "Boolean");
        }
        static d(a) {
            VirtualDataSourceDescriptionMetadata.b(a);
            a.aa("VirtualDataSource", () => new VirtualDataSourceDescription());
            a.z("VirtualDataSource", VirtualDataSourceDescriptionMetadata.a);
        }
    }
    VirtualDataSourceDescriptionMetadata.$t = /*@__PURE__*/ markType(VirtualDataSourceDescriptionMetadata, 'VirtualDataSourceDescriptionMetadata');
    VirtualDataSourceDescriptionMetadata.a = null;
    return VirtualDataSourceDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/VirtualDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { BaseDataSourceDescriptionMetadata } from "./BaseDataSourceDescriptionMetadata";
import { VirtualDataSourceDescription } from "./VirtualDataSourceDescription";
/**
 * @hidden
 */
export let VirtualDataSourceDescriptionMetadata = /*@__PURE__*/ (() => {
    class VirtualDataSourceDescriptionMetadata extends Base {
        static b(a) {
            if (VirtualDataSourceDescriptionMetadata.a == null) {
                VirtualDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                VirtualDataSourceDescriptionMetadata.c(VirtualDataSourceDescriptionMetadata.a);
            }
            if (a.k(VirtualDataSourceDescriptionMetadata.a)) {
                return;
            }
            a.aa(VirtualDataSourceDescriptionMetadata.a);
        }
        static c(a) {
            BaseDataSourceDescriptionMetadata.c(a);
            a.item("IsSectionCollapsable", "Boolean");
            a.item("IsSectionExpandedDefault", "Boolean");
            a.item("PageSizeRequested", "Number:int");
            a.item("MaxCachedPages", "Number:int");
            a.item("ActualPageSize", "Number:int");
            a.item("ConcurrencyTag", "String");
            a.item("IsBatchingEnabled", "Boolean");
        }
        static d(a) {
            VirtualDataSourceDescriptionMetadata.b(a);
            a.ac("VirtualDataSource", () => new VirtualDataSourceDescription());
            a.ab("VirtualDataSource", VirtualDataSourceDescriptionMetadata.a);
        }
    }
    VirtualDataSourceDescriptionMetadata.$t = /*@__PURE__*/ markType(VirtualDataSourceDescriptionMetadata, 'VirtualDataSourceDescriptionMetadata');
    VirtualDataSourceDescriptionMetadata.a = null;
    return VirtualDataSourceDescriptionMetadata;
})();
